#! /usr/bin/env node
"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const yargs_1 = __importDefault(require("yargs"));
const exception_1 = __importDefault(require("./handler/exception"));
const lookup_1 = __importDefault(require("./handler/lookup"));
const translation_1 = __importDefault(require("./handler/translation"));
const ping_1 = __importDefault(require("./handler/ping"));
const tcping_1 = __importDefault(require("./handler/tcping"));
(0, exception_1.default)(() => {
    const { argv } = yargs_1.default
        .command(['translate <text>', 't'], 'Translation module.', {
        source: {
            description: 'Source language for recognization.',
            alias: 's',
            type: 'string',
        },
        target: {
            description: 'Target language for translation.',
            alias: 't',
            type: 'string',
        },
    })
        .command(['lookup <domain>', 'l'], 'DNS lookup module.')
        .command(['ping <ip>', 'p'], 'Ping IP or host module.')
        .command(['tcping <host> <port>', 'tcp'], 'Ping IP or host port module.')
        .help()
        .alias('h', 'help');
    if (['translate', 't'].includes(argv._[0]) && argv.text) {
        (0, translation_1.default)({
            text: argv.text,
            source: argv.source,
            target: argv.target,
        });
    }
    else if (['lookup', 'l'].includes(argv._[0]) && argv.domain) {
        (0, lookup_1.default)(argv.domain);
    }
    else if (['ping', 'p'].includes(argv._[0]) && argv.ip) {
        (0, ping_1.default)(argv.ip);
    }
    else if (['tcping', 'tcp'].includes(argv._[0]) && argv.host && argv.port) {
        (0, tcping_1.default)({
            host: argv.host,
            port: argv.port,
        });
    }
    else {
        throw new Error('SHOW_HELP_ERROR');
    }
});
